@@ -14,8 +14,6 @@ from pathlib import Path
 from posixpath import join as pjoin
 from pprint import pformat
 from typing import TYPE_CHECKING
-from typing import Iterable
-from typing import Iterator
 
 from poetry.core.masonry.builders.builder import Builder
 from poetry.core.masonry.builders.builder import BuildIncludeFile
@@ -23,6 +21,8 @@ from poetry.core.masonry.utils.helpers import distribution_name
 
 
 if TYPE_CHECKING:
+    from collections.abc import Iterable
+    from collections.abc import Iterator
     from tarfile import TarInfo
 
     from poetry.core.masonry.utils.package_include import PackageInclude
@@ -280,18 +280,16 @@ class SdistBuilder(Builder):
                 continue
 
             is_subpkg = any(
-                [filename.endswith(".py") for filename in filenames]
+                filename.endswith(".py") for filename in filenames
             ) and not all(
-                [
-                    self.is_excluded(Path(path, filename).relative_to(self._path))
-                    for filename in filenames
-                    if filename.endswith(".py")
-                ]
+                self.is_excluded(Path(path, filename).relative_to(self._path))
+                for filename in filenames
+                if filename.endswith(".py")
             )
             if is_subpkg:
                 subpkg_paths.add(from_top_level)
                 parts = from_top_level.split(os.sep)
-                packages.append(".".join([pkg_name] + parts))
+                packages.append(".".join([pkg_name, *parts]))
             else:
                 pkg, from_nearest_pkg = find_nearest_pkg(from_top_level)
 
